# aiomaxbot

Пакет Python для AIOMaxBot.

## Установка

```bash
pip install aiomaxbot
```

## Использование

```python
import aiomaxbot

# Использование пакета
print(aiomaxbot.hello())
print(await aiomaxbot.async_hello())
```

## Лицензия

Этот проект лицензирован в соответствии с лицензией MIT - подробности см. в файле [LICENSE](LICENSE).
